@@ -32,7 +32,7 @@ class Client:
             sys.exit()
         self.hashtag_list = config.get("hashtag_list","photos")
         self.current_hashtag = None
-        self.path = os.path.abspath(os.path.dirname(__file__))
+        self.path = config.get("path", os.getcwd()) + "/"
         self.debug = config.get("debug", False)
         self.follow_profiles_list = config.get("follow_profiles", None)
         self.chromedriver_path = config.get("chromedriver_path", "/usr/lib/chromium-browser/chromedriver")
